@@ -11,7 +11,7 @@ from allianceauth.services.hooks import get_extension_logger
 
 from .. import __title__
 from .esi_fetch import esi_fetch, _esi_client
-from ..utils import LoggerAddTag
+from app_utils.logging import LoggerAddTag
 
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
