@@ -11,6 +11,8 @@ from allianceauth.eveonline.providers import ObjectNotFound
 from allianceauth.notifications import notify
 from allianceauth.services.hooks import get_extension_logger
 
+from app_utils.helpers import chunks
+from app_utils.logging import LoggerAddTag
 from esi.models import Token
 
 from . import __title__
@@ -20,14 +22,12 @@ from .app_settings import (
     SR_NOTIFICATIONS_ENABLED,
 )
 from .helpers.esi_fetch import esi_fetch
-from .utils import chunks, LoggerAddTag
 
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
 class ContactSetManager(models.Manager):
-    @transaction.atomic
     def create_new_from_api(self) -> object:
         """fetches contacts with standings for configured alliance
         or corporation from ESI and stores them as newly created ContactSet
@@ -51,9 +51,11 @@ class ContactSetManager(models.Manager):
             )
             return None
 
-        contacts_set = self.create()
-        self._add_labels_from_api(contacts_set, contacts.allianceLabels)
-        self._add_contacts_from_api(contacts_set, contacts.alliance)
+        with transaction.atomic():
+            contacts_set = self.create()
+            self._add_labels_from_api(contacts_set, contacts.allianceLabels)
+            self._add_contacts_from_api(contacts_set, contacts.alliance)
+
         return contacts_set
 
     def _add_labels_from_api(self, contact_set, labels):
@@ -321,12 +323,7 @@ class AbstractStandingsRequestManager(models.Manager):
 
         returns True if a request is already pending, False otherwise
         """
-        return (
-            self.filter(contact_id=contact_id)
-            .filter(action_date=None)
-            .filter(is_effective=False)
-            .exists()
-        )
+        return self.pending_requests().filter(contact_id=contact_id).exists()
 
     def has_actioned_request(self, contact_id: int) -> bool:
         """Checks if an actioned request is pending API confirmation for
@@ -338,7 +335,7 @@ class AbstractStandingsRequestManager(models.Manager):
         """
         return (
             self.filter(contact_id=contact_id)
-            .exclude(action_by=None)
+            .exclude(action_date__isnull=True)
             .filter(is_effective=False)
             .exists()
         )
@@ -349,11 +346,9 @@ class AbstractStandingsRequestManager(models.Manager):
         """
         return self.filter(contact_id=contact_id).filter(is_effective=True).exists()
 
-    def pending_requests_count(self) -> int:
-        """returns the number of pending requests for this category"""
-        return (
-            self.filter(action_by__exact=None).filter(is_effective__exact=False).count()
-        )
+    def pending_requests(self) -> models.QuerySet:
+        """returns all pending requests for this class"""
+        return self.filter(action_date__isnull=True).filter(is_effective=False)
 
 
 class StandingRequestManager(AbstractStandingsRequestManager):
