@@ -30,7 +30,7 @@ from .managers import (
     StandingRequestManager,
     StandingRevocationManager,
 )
-from .utils import LoggerAddTag
+from app_utils.logging import LoggerAddTag
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
